summaryrefslogtreecommitdiff
path: root/src/mongo/executor/network_connection_hook.h
diff options
context:
space:
mode:
authorLucas de Castro Borges <lucas@gnuabordo.com.br>2025-02-11 15:07:35 -0300
committerLucas de Castro Borges <lucas@gnuabordo.com.br>2025-02-11 15:07:35 -0300
commit4cb8841196d0625dfa3825aa326f071cd27c7b8b (patch)
tree1682a647d4463397c119183369ae6f750d5fdcff /src/mongo/executor/network_connection_hook.h
parentaa03c6362cbaa767638e6eed9b031d86dd2643d1 (diff)
parent8f0827553e09872941945a093b647a4211a9db7f (diff)
Update upstream source from tag 'upstream/6.0.0'master
Update to upstream version '6.0.0' with Debian dir 5604a80ec1c96ca76f25f40d78e6ef855abec322
Diffstat (limited to 'src/mongo/executor/network_connection_hook.h')
-rw-r--r--src/mongo/executor/network_connection_hook.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/mongo/executor/network_connection_hook.h b/src/mongo/executor/network_connection_hook.h
index 8510344c85a..04de5571cb6 100644
--- a/src/mongo/executor/network_connection_hook.h
+++ b/src/mongo/executor/network_connection_hook.h
@@ -54,16 +54,16 @@ public:
virtual ~NetworkConnectionHook() = default;
/**
* Optionally augments the "hello" request sent while initializing the wire protocol.
*
* By default this will just return the cmdObj passed in unaltered.
*/
- virtual BSONObj augmentHelloRequest(const HostAndPort& remoteHost, BSONObj cmdObj) {
+ virtual BSONObj augmentIsMasterRequest(const HostAndPort& remoteHost, BSONObj cmdObj) {
return cmdObj;
}
/**
* Runs optional validation logic on an "hello" reply from a remote host. If a non-OK
* Status is returned, it will be propagated up to the completion handler for the command
* that initiated the request that caused this connection to be created. This will
* be called once for each connection that is created, even if a remote host with the
@@ -77,8 +77,8 @@ public:
* std::terminate.
*/
virtual Status validateHost(const HostAndPort& remoteHost,
- const BSONObj& helloRequest,
- const RemoteCommandResponse& helloReply) = 0;
+ const BSONObj& isMasterRequest,
+ const RemoteCommandResponse& isMasterReply) = 0;
/**
* Generates a command to run on the remote host immediately after connecting to it.
@@ -54,16 +54,16 @@ public:
virtual ~NetworkConnectionHook() = default;
/**
- * Optionally augments the "hello" request sent while initializing the wire protocol.
+ * Optionally augments the isMaster request sent while initializing the wire protocol.
*
* By default this will just return the cmdObj passed in unaltered.
@@ -54,16 +54,16 @@ public:
}
/**
- * Runs optional validation logic on an "hello" reply from a remote host. If a non-OK
+ * Runs optional validation logic on an isMaster reply from a remote host. If a non-OK
* Status is returned, it will be propagated up to the completion handler for the command
* that initiated the request that caused this connection to be created. This will